@@ -9,13 +9,16 @@ class CWUtils:  # pylint: disable=too-few-public-methods
     """
 
     @staticmethod
-    def put_lambda_metric(cw_client, metric_name: str, dai_code: str, function_name: str):
+    def put_lambda_metric(
+        cw_client, metric_name: str, dai_code: str, function_name: str, value: int = 1
+    ):
         """
         Increase counter for our dai-code metric for its kind of action in cloudwatch.
 
         :param cw_client: A boto3.client("cloudwatch") to use to write the logs
         :param metric_name: Which counter to increase
         :param dai_code: The dai_code (e.g. `tr-tms-obs-0008`) which will be used for setting the dimension of the metric
+        :param value: The amount of processed enteties to report.
         :param function_name: The lambda name which will be used for setting the namespace of the metric
         """
         allowed_metric_names = ["invocation", "error", "validationError"]
@@ -27,7 +30,7 @@ class CWUtils:  # pylint: disable=too-few-public-methods
             MetricData=[
                 {
                     "MetricName": metric_name,
-                    "Value": 1,
+                    "Value": value,
                     "Unit": "Count",
                     "Dimensions": [{"Name": "daiCode", "Value": dai_code}],
                 }
